# Databricks Extension for PandaAI

This extension integrates Databricks connectors with PandaAI, providing support for Databricks.

## Installation

You can install this extension using poetry:

```bash
poetry install pandasai-databricks
```

## License

This package is licensed under the Sinaptik GmbH Enterprise License.  
For commercial use, please contact [pm@sinaptik.ai](mailto:pm@sinaptik.ai).
